==> apache-inlong-1.5.0-src.tar.gz: apache-inlong-1.5.0/inlong-sort/sort-formats/format-common/src/test/java/org/apache/inlong/sort/formats/common/MapFormatInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.formats.common;

import java.util.Arrays;
import java.util.Collection;

/**
 * Unit tests for {@link MapFormatInfo}.
 */
public class MapFormatInfoTest extends FormatInfoTestBase {

    @Override
    Collection<FormatInfo> createFormatInfos() {
        MapFormatInfo formatInfo1 =
                new MapFormatInfo(
                        StringFormatInfo.INSTANCE,
                        IntFormatInfo.INSTANCE);

        MapFormatInfo formatInfo2 =
                new MapFormatInfo(
                        new ArrayFormatInfo(IntFormatInfo.INSTANCE),
                        new TimeFormatInfo("MILLIS"));

        MapFormatInfo formatInfo3 =
                new MapFormatInfo(
                        new MapFormatInfo(
                                StringFormatInfo.INSTANCE,
                                FloatFormatInfo.INSTANCE),
                        new ArrayFormatInfo(BooleanFormatInfo.INSTANCE));

        return Arrays.asList(formatInfo1, formatInfo2, formatInfo3);
    }
}

==> apache-inlong-2.3.0-src.tar.gz: apache-inlong-2.3.0/inlong-sort/sort-formats/format-common/src/test/java/org/apache/inlong/sort/formats/common/MapFormatInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.formats.common;

import org.apache.inlong.common.pojo.sort.dataflow.field.format.ArrayFormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.BooleanFormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.FloatFormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.FormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.IntFormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.MapFormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.StringFormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.TimeFormatInfo;

import java.util.Arrays;
import java.util.Collection;

/**
 * Unit tests for {@link MapFormatInfo}.
 */
public class MapFormatInfoTest extends FormatInfoTestBase {

    @Override
    Collection<FormatInfo> createFormatInfos() {
        MapFormatInfo formatInfo1 =
                new MapFormatInfo(
                        StringFormatInfo.INSTANCE,
                        IntFormatInfo.INSTANCE);

        MapFormatInfo formatInfo2 =
                new MapFormatInfo(
                        new ArrayFormatInfo(IntFormatInfo.INSTANCE),
                        new TimeFormatInfo("MILLIS"));

        MapFormatInfo formatInfo3 =
                new MapFormatInfo(
                        new MapFormatInfo(
                                StringFormatInfo.INSTANCE,
                                FloatFormatInfo.INSTANCE),
                        new ArrayFormatInfo(BooleanFormatInfo.INSTANCE));

        return Arrays.asList(formatInfo1, formatInfo2, formatInfo3);
    }
}
